%global service keystone
%global common_desc \
Keystone is a Python implementation of the OpenStack \
(http://www.openstack.org) identity service API.

Summary:        OpenStack Identity Service
Name:           openstack-%{service}
Version:        19.0.0
Release:        3%{?dist}
License:        ASL 2.0
URL:            http://keystone.openstack.org/
Source0:        https://tarballs.openstack.org/%{service}/%{service}-%{version}.tar.gz
Source1:        %{name}.logrotate
Source2:        %{name}.sysctl
Source3:        %{name}-sample-data
Source4:        %{service}-dist.conf
Patch0001:      0001-Hide_AccountLocked.patch
Patch0002:      backport-Replace-deprecated-import-of-ABCs-from-coll.patch

BuildArch:      noarch

BuildRequires:  python3-devel python3-pbr python3-passlib python3-pycadf
BuildRequires:  python3-oslo-cache python3-oslo-config python3-oslo-messaging
BuildRequires:  python3-oslo-db python3-oslo-policy
BuildRequires:  python3-jsonschema python3-oauthlib python3-pysaml2
BuildRequires:  python3-keystonemiddleware python3-osprofiler
BuildRequires:  systemd
Requires:       python3-%{service} = %{version}-%{release}
Requires(pre):  shadow-utils

%{?systemd_ordering}

%description
%{common_desc}

%package -n python3-%{service}
Summary:        Keystone Python libraries

Requires:       python3-pbr python3-webob python3-flask python3-flask-restful
Requires:       python3-cryptography python3-sqlalchemy python3-migrate
Requires:       python3-stevedore python3-passlib python3-keystoneclient
Requires:       python3-keystonemiddleware python3-bcrypt python3-scrypt
Requires:       python3-oslo-cache python3-oslo-config python3-oslo-context
Requires:       python3-oslo-db python3-oslo-i18n python3-oslo-log
Requires:       python3-oslo-messaging python3-oslo-middleware python3-oslo-policy
Requires:       python3-oslo-serialization python3-oslo-upgradecheck python3-oslo-utils
Requires:       python3-oauthlib python3-pysaml2 python3-jwt python3-dogpile-cache
Requires:       python3-jsonschema python3-pycadf python3-msgpack python3-osprofiler
Requires:       python3-pytz
Requires:       openssl

%description -n python3-%{service}
%{common_desc}

%prep
%autosetup -n %{service}-%{version} -p1

find . \( -name .gitignore -o -name .placeholder \) -delete
find keystone -name \*.py -exec sed -i '/\/usr\/bin\/env python/d' {} \;

sed -i 's#/local/bin#/bin#' httpd/wsgi-keystone.conf
sed -i 's#apache2#httpd#' httpd/wsgi-keystone.conf

%build
PYTHONPATH=. oslo-config-generator --config-file=config-generator/keystone.conf
PYTHONPATH=. oslo-config-generator --config-file=config-generator/keystone.conf --format yaml --output-file=%{service}-schema.yaml
PYTHONPATH=. oslo-config-generator --config-file=config-generator/keystone.conf --format json --output-file=%{service}-schema.json

%{py3_build}
%{__python3} setup.py compile_catalog -d build/lib/%{service}/locale -D keystone

%install
%{py3_install}

echo "{}" > policy.json

install -p -D -m 755 %{SOURCE3} %{buildroot}%{_bindir}/openstack-keystone-sample-data
install -d -m 755 %{buildroot}%{_sysconfdir}/keystone
install -d -m 755 %{buildroot}%{_sysconfdir}/keystone/policy.d
install -p -D -m 640 etc/keystone.conf.sample %{buildroot}%{_sysconfdir}/keystone/keystone.conf
install -p -D -m 640 policy.json %{buildroot}%{_sysconfdir}/keystone/policy.json
install -p -D -m 640 etc/logging.conf.sample %{buildroot}%{_sysconfdir}/keystone/logging.conf
install -p -D -m 640 etc/default_catalog.templates %{buildroot}%{_sysconfdir}/keystone/default_catalog.templates
install -p -D -m 640 etc/sso_callback_template.html %{buildroot}%{_sysconfdir}/keystone/sso_callback_template.html
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/logrotate.d/openstack-keystone
install -d -m 755 %{buildroot}%{_datadir}
install -p -D -m 640 %{service}-schema.yaml %{buildroot}%{_datadir}/%{service}/%{service}-schema.yaml
install -p -D -m 640 %{service}-schema.json %{buildroot}%{_datadir}/%{service}/%{service}-schema.json
install -p -D -m 644 %{SOURCE4} %{buildroot}%{_datadir}/keystone/keystone-dist.conf
install -p -D -m 755 tools/sample_data.sh %{buildroot}%{_datadir}/keystone/sample_data.sh
install -p -D -m 644 httpd/wsgi-keystone.conf  %{buildroot}%{_datadir}/keystone/
rm -f %{buildroot}%{python3_sitelib}/%{service}/locale/*/LC_*/%{service}*po
rm -f %{buildroot}%{python3_sitelib}/%{service}/locale/*pot
mv %{buildroot}%{python3_sitelib}/%{service}/locale %{buildroot}%{_datadir}/locale

install -d -m 755 %{buildroot}%{_prefix}/lib/sysctl.d
install -p -D -m 644 %{SOURCE2} %{buildroot}%{_prefix}/lib/sysctl.d/openstack-keystone.conf
install -d -m 755 %{buildroot}%{_sharedstatedir}/keystone
install -d -m 755 %{buildroot}%{_localstatedir}/log/keystone

rm -rf %{buildroot}/%{_prefix}%{_sysconfdir}

%find_lang %{service} --all-name

%pre
getent group keystone >/dev/null || groupadd -r --gid 163 keystone
getent passwd keystone >/dev/null || \
useradd --uid 163 -r -g keystone -d %{_sharedstatedir}/keystone -s /sbin/nologin \
-c "OpenStack Keystone Daemons" keystone
exit 0

%post
%sysctl_apply openstack-keystone.conf
touch %{_localstatedir}/log/keystone/keystone.log
chown root:keystone %{_localstatedir}/log/keystone/keystone.log
chmod 660 %{_localstatedir}/log/keystone/keystone.log

%files
%license LICENSE
%doc README.rst
%{_bindir}/keystone-wsgi-admin
%{_bindir}/keystone-wsgi-public
%{_bindir}/keystone-manage
%{_bindir}/keystone-status
%{_bindir}/openstack-keystone-sample-data
%dir %{_datadir}/keystone
%attr(0644, root, keystone) %{_datadir}/keystone/keystone-dist.conf
%attr(0644, root, keystone) %{_datadir}/keystone/%{service}-schema.yaml
%attr(0644, root, keystone) %{_datadir}/keystone/%{service}-schema.json
%attr(0755, root, root) %{_datadir}/keystone/sample_data.sh
%attr(0644, root, keystone) %{_datadir}/keystone/wsgi-keystone.conf
%dir %attr(0750, root, keystone) %{_sysconfdir}/keystone
%dir %attr(0750, root, keystone) %{_sysconfdir}/keystone/policy.d
%config(noreplace) %attr(0640, root, keystone) %{_sysconfdir}/keystone/keystone.conf
%config(noreplace) %attr(0640, root, keystone) %{_sysconfdir}/keystone/logging.conf
%config(noreplace) %attr(0640, root, keystone) %{_sysconfdir}/keystone/policy.json
%config(noreplace) %attr(0640, root, keystone) %{_sysconfdir}/keystone/default_catalog.templates
%config(noreplace) %attr(0640, keystone, keystone) %{_sysconfdir}/keystone/sso_callback_template.html
%config(noreplace) %{_sysconfdir}/logrotate.d/openstack-keystone
%dir %attr(-, keystone, keystone) %{_sharedstatedir}/keystone
%dir %attr(0750, keystone, keystone) %{_localstatedir}/log/keystone
%ghost %attr(0660, root, keystone) %{_localstatedir}/log/keystone/keystone.log
%{_prefix}/lib/sysctl.d/openstack-keystone.conf

%files -n python3-%{service} -f %{service}.lang
%license LICENSE
%defattr(-,root,root,-)
%{python3_sitelib}/keystone
%{python3_sitelib}/keystone-*.egg-info

%changelog
* Mon May 15 2023 abushwang <abushwang@tencent.com> - 19.0.0-3
- backport Replace deprecated import of ABCs from collections

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 19.0.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 19 2023 kianli <kianli@tencent.com> - 19.0.0-1
- initial build
